@@ -1,7 +1,10 @@
 """Representation of a mesh device"""
 
 import datetime
-from typing import List
+from typing import (
+    List,
+    Optional,
+)
 
 from .base import MeshDevice
 
@@ -57,6 +60,40 @@ class Device(MeshDevice):
         :param kwargs: keyword arguments
         """
         super().__init__(**kwargs)
+        self.__parent_name: Optional[str] = None
+
+    @property
+    def description(self) -> Optional[str]:
+        """Get the description"""
+
+        return self._attribs.get("model", {}).get("description", None)
+
+    @property
+    def manufacturer(self) -> Optional[str]:
+        """Get the manufacturer"""
+
+        return (
+                self._get_user_property(name="userDeviceManufacturer")
+                or self._attribs.get("model", {}).get("manufacturer", None)
+        )
+
+    @property
+    def model(self) -> Optional[str]:
+        """Get the model"""
+
+        return (
+            self._get_user_property(name="userDeviceModelNumber")
+            or self._attribs.get("model", {}).get("modelNumber", None)
+        )
+
+    @property
+    def operating_system(self) -> Optional[str]:
+        """Get the OS"""
+
+        return (
+                self._get_user_property(name="userDeviceOS")
+                or self._attribs.get("unit", {}).get("operatingSystem", None)
+        )
 
     @property
     def parental_control_schedule(self) -> dict:
@@ -74,3 +111,15 @@ class Device(MeshDevice):
                 }
 
         return ret
+
+    @property
+    def parent_name(self) -> Optional[str]:
+        """Name of the node the device is connected to"""
+
+        return self.__parent_name
+
+    @property
+    def serial(self) -> Optional[str]:
+        """Get the serial number"""
+
+        return self._attribs.get("unit", {}).get("serialNumber", None)
