@@ -1,11 +1,19 @@
 """Represents a node in the mesh"""
-from typing import List, Optional, Union
+
+# region #-- imports --#
+from __future__ import annotations
+
+from typing import (
+    List,
+    Optional,
+)
 
 from .base import MeshDevice
-from .const import (
-    NODE_TYPE_PRIMARY,
-    NODE_TYPE_SECONDARY,
-)
+
+# endregion
+
+NODE_TYPE_PRIMARY = "primary"
+NODE_TYPE_SECONDARY = "secondary"
 
 
 class Node(MeshDevice):
@@ -110,7 +118,7 @@ class Node(MeshDevice):
         return self._attribs.get("model", {}).get("modelNumber")
 
     @property
-    def parent_ip(self) -> Union[str, None]:
+    def parent_ip(self) -> Optional[str]:
         """Get the IP address of the node that this node is attached to.
 
         :return: A string containing the IP address of the parent or None if no parent
